package com.akamai.tvuisample;

import android.os.Bundle;
import android.app.Activity;
import android.util.Log;
import android.view.KeyEvent;
import android.view.WindowManager;
import android.widget.ProgressBar;

import com.akamai.androidsdk_uitv_module.MediaControlBarManager;
import com.akamai.androidsdk_uitv_module.MediaPlayerController;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;

public class MainActivity extends Activity implements
        MediaControlBarManager.OnRemoteControlActionsListener,
        IPlayerEventsListener, VideoPlayerContainer.VideoPlayerContainerCallback {

    private final static String TAG = "AMPv6";
    private final static String LICENSE = "UGOPNTtdFND2kYXBta8AqFofTllQnSMeoM1djl95WMI6qE6bz9v6MWPIdXAKjIQPVED1LOSBl4gkB3KmJQB0aA==";
    private final static String VIDEO_URL = "http://multiplatform-f.akamaihd.net/i/multi/will/bunny/big_buck_bunny_,640x360_400,640x360_700,640x360_1000,950x540_1500,.f4v.csmil/master.m3u8";

    private VideoPlayerContainer mVideoPlayerContainer;
    private VideoPlayerView mVideoPlayerView;
    private ProgressBar mProgressBar;
    private MediaPlayerController mediaPlayerController;
    private MediaControlBarManager mediaControlBarManager;

    private MediaResource resource;

    private boolean mWasPlaying = false;
    private int mCurrentPosition = 0;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
        mediaPlayerController = (MediaPlayerController)
                getFragmentManager().findFragmentById(R.id.playback_controls_fragment);
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
        mVideoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoPlayerContainer.addVideoPlayerContainerCallback(this);
        mVideoPlayerContainer.prepareResource(VIDEO_URL);
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        resource = mediaResource;
        mVideoPlayerView = mVideoPlayerContainer.getVideoPlayer();
        mediaControlBarManager = new MediaControlBarManager(this, this, mediaPlayerController);
        mediaControlBarManager.CCActionEnabled(false);
        mediaControlBarManager.setVideoPlayerView(mVideoPlayerView);
        mVideoPlayerView.setProgressBarControl(mProgressBar);
        mVideoPlayerView.setLicense(LICENSE);
        mVideoPlayerView.play(resource, mCurrentPosition);
    }


    @Override
    public boolean onRemoteActionReceived(MediaControlBarManager.RemoteControlAction action){
        switch (action) {
            case PLAY:
                return true;
            case PAUSE:
                return true;
            case FAST_FORWARD:
                return true;
            case REWIND:
                return true;
            case CAPTION_ON:
                return true;
            case CAPTION_OFF:
                return true;
            default:
                return false;
        }
    }


    @Override
    public void onVideoPlayerCreated() {
        Log.i(TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceError() {
        Log.e(TAG, "onResourceError()");
    }

    @Override
    protected void onResume() {
        Log.d(TAG, "onResume");

        if (mWasPlaying) {
            mVideoPlayerView.play(resource, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d(TAG, "onPause");

        boolean shouldStop = (mVideoPlayerView != null) && (mVideoPlayerView.isPlaying() || mVideoPlayerView.isPaused());
        if (shouldStop) {
            mCurrentPosition = mVideoPlayerView.getTimePosition();
            mWasPlaying = true;
            mVideoPlayerView.stop();
        }

        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d(TAG, "onDestroy");
        if(mVideoPlayerView != null){
            mVideoPlayerView.stop();
            mVideoPlayerView.onDestroy();
        }

        super.onDestroy();
    }

    @Override
    public boolean onKeyUp(int keyCode, KeyEvent event) {
        if(mediaControlBarManager != null){
            return mediaControlBarManager.handleRemoteControlActions(keyCode);
        }
        return super.onKeyUp(keyCode, event);
    }


    @Override
    public boolean onPlayerEvent(int iInEventType) {
        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        return true;
    }

}
